ControlsConfig class

Constructors

ControlsConfig({bool? viewsCounter, bool? disablePause, bool? liveRewind, bool? autoPlay, bool? liveIcon})
ControlsConfig.fromJson(Map<String, dynamic>? json)
factory

Properties

autoPlay → bool?
final
disablePause → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
liveIcon → bool?
final
liveRewind → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewsCounter → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited